package com.caimei.www.service.impl;

import com.caimei.module.base.entity.bo.JsonModel;
import com.caimei.www.mapper.HomeDao;
import com.caimei.www.pojo.HomeFloor;
import com.caimei.www.pojo.ImageLink;
import com.caimei.www.pojo.ProductList;
import com.caimei.www.pojo.SubMenu;
import com.caimei.www.service.HomeService;
import com.caimei.www.utils.PriceUtil;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2020/6/22
 */
@Service
public class HomeServiceImpl implements HomeService {
    @Resource
    private HomeDao homeDao;

    /**
     * 首页楼层
     */
    @Override
    public List<HomeFloor> getHomePageFloor() {
        List<HomeFloor> floorList = homeDao.getHomePageFloor();
        return floorList;
    }

    /**
     * 首页轮播图
     */
    @Override
    @Cacheable(value = "getHomeBanners", key="'www'", unless="#result == null")
    public JsonModel getHomeBanners() {
        List<ImageLink> list = homeDao.getHomeBanners();
        return JsonModel.newInstance().success(list);
    }

    /**
     * 首页左侧广告图
     */
    @Override
    @Cacheable(value = "getAdvertising", key="'www'", unless="#result == null")
    public JsonModel getAdvertising() {
        List<ImageLink> list = homeDao.getAdvertising();
        return JsonModel.newInstance().success(list);
    }

    /**
     * 首页推荐专区商品
     */
    @Override
    @Cacheable(value = "getRecommendProducts", key="'www'", unless="#result == null")
    public JsonModel getRecommendProducts() {
        List<ProductList> list = homeDao.getRecommendeds();
        if (list.size() > 0) {
            // 设置价格等级
            list.forEach(product -> {
                 product.setPricegrade(PriceUtil.getPriceGrade(product.getPrice()));
                 product.setPrice(0d);
            });
        }
        return JsonModel.newInstance().success(list);
    }

    /**
     * 首页专题数据
     */
    @Override
    public JsonModel getHomeTopicData() {
        // 大专题:6,小专题:5,商品专题:4,优质供应商:3
        Map<String, Object> topicMap = new HashMap<>();
        // 6大专题二级楼层
        List<HomeFloor> bigTopicFloors = homeDao.getHomeBigTopicFloor();
        bigTopicFloors.forEach(bigTopic -> {
            List<ImageLink>  topicData = homeDao.getBigTopicData(bigTopic.getId());
            bigTopic.setFloorData(topicData);
        });
        topicMap.put("bigTopicData", bigTopicFloors);
        // 专题4
        List<ImageLink>  topicData4 = homeDao.getCommodityTopicData();
        topicMap.put("topicData4", topicData4);
        // 专题5
        List<ImageLink>  topicData5 = homeDao.getSmallTopicData();
        topicMap.put("topicData5", topicData5);
        // 专题3
        List<ImageLink>  topicData3 = homeDao.getSuppliersTopData();
        topicMap.put("topicData3", topicData3);

        return JsonModel.newInstance().success(topicMap);
    }

}
